@@ -119,13 +119,16 @@ int split_raw_increment_fname (char *fn)
 
     /* See if it is a number */
     if(isdigit(ext[0]) && isdigit(ext[1]) && isdigit(ext[2])){
-	int num = atoi(ext);
+	unsigned int num = atoi(ext);
 	if(num==999){
 	    strcpy(ext,"A00");
 	    return 0;
+	} else if(num >= 0 && num < 999) {
+	    snprintf(ext,4,"%03d",(num+1) % 1000);
+	    return 0;
+	} else {
+	    return EINVAL;
 	}
-	snprintf(ext,4,"%03d",num+1);
-	return 0;
     }
 
     /* First digit goes A-Z, second and third go 0-9A-Z */
@@ -190,7 +193,6 @@ static int split_raw_open_internal(AFFILE *af, uint64_t *image_size)
 {
     struct split_raw_private *srp = SPLIT_RAW_PRIVATE(af);
     int fd;
-    struct stat sb;
 
     fd = open(srp->first_raw_fname, af->openflags|O_BINARY, af->openmode);
     if (fd < 0) {
@@ -202,7 +204,13 @@ static int split_raw_open_internal(AFFILE *af, uint64_t *image_size)
     srp->fds = (int *)malloc (sizeof (int));
     srp->fds[0] = fd;
     srp->pos = (uint64_t *)malloc (sizeof (uint64_t));
+#ifdef _WIN32
+	struct _stat64 sb;
+	if (_fstat64(fd, &sb) != 0) {
+#else
+	struct stat sb;
     if (fstat (fd, &sb) != 0) {
+#endif
       (*af->error_reporter)("split_raw_open_internal: fstat(%s): ",af->fname);
 	close (fd);
 	srp->fds[0] = 0;
@@ -254,7 +262,11 @@ static int split_raw_open_internal(AFFILE *af, uint64_t *image_size)
 	   af_open returns.  */
 	if (!af->maxsize)
 	    af->maxsize = sb.st_size;
+#ifdef _WIN32
+	if (_fstat64(fd, &sb) != 0) {
+#else
 	if (fstat (fd, &sb) != 0) {
+#endif
 	  (*af->error_reporter)("split_raw_open_internal: fstat(%s): ",af->fname);
 	    return -1;
 	}
